@@ -1,7 +1,8 @@
 <?php
 /*
  * Phamm - http://www.phamm.org - <team AT phamm DOT org>
- * Copyright (C) 2004-2005 Alessandro De Zorzi and Mirko Grava
+ * Copyright (C) 2004,2008 Alessandro De Zorzi and Mirko Grava
+ * Project sponsored by RHX Studio Associato - www.rhx.it
  *  
  * Phamm is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,7 +44,7 @@ define ('LDAP_PORT','389');
 define ('SUFFIX','dc=example,dc=tld');
 
 // The admin bind dn (could be rootdn)
-define ('BINDDN','cn=manager,dc=example,dc=tld');
+define ('BINDDN','cn=admin,dc=example,dc=tld');
 
 // The Phamm container
 define ('LDAP_BASE','o=hosting,dc=example,dc=tld');
@@ -53,7 +54,7 @@ define ('LDAP_BASE','o=hosting,dc=example,dc=tld');
 // *============================*
 
 // Phamm Version (+ indicate a CVS version)
-define ('VERSION','0.5.9');
+define ('VERSION','0.5.12');
 
 // Useful if you want hide the version [0,1]
 define ('HIDE_VERSION',0);
@@ -200,7 +201,7 @@ $tld[] = ".net";
 define ('DEBUG',0);
 
 // PHP Error Level [0,1,2,10]
-define ('ERROR_LEVEL',1);
+define ('ERROR_LEVEL',2);
 
 // Only for advanced users
 define ('ADVANCED_VIEW',0);
@@ -209,7 +210,7 @@ define ('ADVANCED_VIEW',0);
 define ('PHAMM_LOG',0);
 
 // Log file path
-define ('LOG_FILE','/tmp/phamm.log');
+define ('LOG_FILE','/var/log/phamm.log');
 
 // Standard LDAP encryption type [CRYPT,MD5,CLEAR]
 define ('ENC_TYPE','CRYPT');
