@@ -7,7 +7,7 @@
 
 /*
 * Phamm - http://phamm.rhx.it - <phamm@rhx.it>
-* Copyright (C) 2004,2005 Alessandro De Zorzi and Mirko Grava
+* Copyright (C) 2004,2008 Alessandro De Zorzi and Mirko Grava
 *
 * This file is part of Phamm.
 *  
@@ -38,6 +38,7 @@ function page_start()
     $tag .= '<head>'."\n";
     $tag .= "\t".'<title>'.ORG_TITLE.'</title>'."\n";
     $tag .= "\t".'<style type="text/css" media="all">@import "./style/phamm/main.css";</style>'."\n";
+    $tag .= "\t".'<script type="text/javascript" src="functions.js"></script>'."\n";
     $tag .= '</head>'."\n";
     $tag .= '<body>'."\n";
 
@@ -145,11 +146,11 @@ function domains_list($vds,$values)
 {
     global $lang;
 
-    $tag = '<form method="post" action="'.$_SERVER["PHP_SELF"].'" name="domains">';
+    $tag = '<form method="post" action="'.$_SERVER["PHP_SELF"].'" name="domains" id="post-checks">';
     $tag .= '<table class="data">';
 
     $tag .= '<tr class="header">';
-    $tag .= '<td></td>';
+    $tag .= '<td><input type="checkbox" name="all" onclick="checkAll();" /></td>';
     $tag .= '<td>'.$lang["domain"].' ('.$vds["count"].')</td>'."\n";
 
     if (isset($values["ATTRIBUTES"]))
@@ -183,7 +184,7 @@ function domains_list($vds,$values)
             $tag .= '<td><input type="checkbox" name="domains['.$domain.']" value="1" /></td>';
 
             // Domain name and link
-            $tag .= '<td><a href="?action=domain_view&amp;mail=NONE&amp;domain='.$domain.'" class="inside">';
+            $tag .= '<td><a href="?action=domain_view&amp;mail=NONE&amp;domain='.$domain.'&amp;initial=" class="inside">';
             $tag .= $domain;
             $tag .= '</a></td>';
 
@@ -209,7 +210,9 @@ function domains_list($vds,$values)
 			    // The reverse values
 			    $rev = ($val == 'TRUE' ? 'FALSE' : 'TRUE');
 
-			    if ($val == 'TRUE' || $val == 'FALSE')
+			    if (isset($values["ATTRIBUTES"][$key]["TABLENOEDIT"]))
+				$tag .= $val;
+			    elseif (isset($values["ATTRIBUTES"][$key]["BOOL"]))
 				$tag .= tof_icon('domains['.$domain.']',$val,'domain;'.$key.';'.$rev,$reverse,$cron);
 			    else
 				$tag .= $val;
@@ -248,7 +251,7 @@ function domains_list($vds,$values)
 *
 **/
 
-function accounts_list($domain,$values)
+function accounts_list($domain,$values,$initial)
 {
     global $lang;
     global $pn;
@@ -257,13 +260,16 @@ function accounts_list($domain,$values)
     // Rapresentative ObjectClass
     $myObjectClass = (isset($pv[$pn]["ACCOUNT"]["OBJECTCLASSES"]) ? key($pv[$pn]["ACCOUNT"]["OBJECTCLASSES"]) : 'virtualMailAccount');
 
-    $account_array = phamm_search ('vd='.$domain.','.LDAP_BASE,'(&(objectClass='.$myObjectClass.')(!(cn=postmaster))(!(mail=abuse@*)))');
+    if (isset($initial))
+	$account_array = phamm_search ('vd='.$domain.','.LDAP_BASE,'(&(objectClass='.$myObjectClass.')(!(cn=postmaster))(!(mail=abuse@*))(mail='.$initial.'*))');
+    else
+	$account_array = phamm_search ('vd='.$domain.','.LDAP_BASE,'(&(objectClass='.$myObjectClass.')(!(cn=postmaster))(!(mail=abuse@*)))');
 
-    $tag = '<form method="post" action="'.$_SERVER["PHP_SELF"].'" name="accounts">';
+    $tag = '<form method="post" action="'.$_SERVER["PHP_SELF"].'" name="accounts" id="post-checks">';
     $tag .= '<table class="data">';
 
     $tag .= '<tr class="header">';
-    $tag .= '<td></td>';
+    $tag .= '<td><input type="checkbox" name="all" onclick="checkAll();" /></td>';
     $tag .= '<td>'.$lang["account"].' ('.$account_array["count"].')</td>'."\n";
     $tag .= '<td>'.$lang["cn"].'</td>'."\n";
 
@@ -316,7 +322,9 @@ function accounts_list($domain,$values)
 			    $val = $account[$key_lower][0];
 			    $rev = ($val == 'TRUE' ? 'FALSE' : 'TRUE');
 
-			    if ($val == 'TRUE' || $val == 'FALSE')
+			    if (isset($values["ATTRIBUTES"][$key]["TABLENOEDIT"]))
+				$tag .= $val;
+			    elseif (isset($values["ATTRIBUTES"][$key]["BOOL"]))
 				$tag .= tof_icon('accounts['.$mail.']',$val,'account;'.$key.';'.$rev,$reverse,$cron);
 
 			    // Print Standard Value
@@ -325,7 +333,7 @@ function accounts_list($domain,$values)
 				if (isset($value["MULTIPLIER"]))
 				    $tag .= $account[$key_lower][0] / $value["MULTIPLIER"];
 				else
-				    $tag .= $account[$key_lower][0];
+				    $tag .= $val;
 			    }
 			}
 
@@ -335,6 +343,7 @@ function accounts_list($domain,$values)
             }
 
             $tag .= '</tr>'."\n";
+
         }
     }
 
@@ -388,28 +397,29 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
     if (is_array($attributes))
     foreach ($attributes as $key => $attr)
     {
-	$minAuthLevel = (isset($attr["MINAUTHLEVEL"]) ? $attr["MINAUTHLEVEL"] : 0);
         if (!isset($hidden))
 	    $tag .= '<tr><td>';
-
+        
+	// Set attributes
         $name = strtolower($key);
-
+	$hidden = (isset($attr["HIDDEN"]) ? 'type="hidden"' : null);
+	$minAuthLevel = (isset($attr["MINAUTHLEVEL"]) ? $attr["MINAUTHLEVEL"] : 0);
         $size = (isset($attr["SIZE"]) ? 'size="'.$attr["SIZE"].'"' : null);
 
-        if (isset($attr["MAXLENGHT"]))
-            $maxlength = strtolower($attr["MAXLENGTH"]);
+        $maxlength = (isset($attr["MAXLENGHT"]) ? strtolower($attr["MAXLENGTH"]) : null);
 
-        $hidden = (isset($attr["HIDDEN"]) ? 'type="hidden"' : null);
         $subordinated = (isset($attr["SUBORDINATED"]) ? strtoupper($attr["SUBORDINATED"]) : null);
-        $required = (isset($attr["REQUIRED"]) ? ' *' : null);
+        $subordinatedreverse = (isset($attr["SUBORDINATEDREVERSE"]) ? strtoupper($attr["SUBORDINATEDREVERSE"]) : null);
+        
+	// Set XHTML Tags
+	$required = (isset($attr["REQUIRED"]) ? ' *' : null);
 
+	// Set Default value
         $value = '';
 
-        // Default value
+        // Set standard value
         if (isset($myvalues[$p_name][$name]))
-        {
-                $value = $myvalues[$p_name][$name];
-        }
+            $value = $myvalues[$p_name][$name];
         
 	// Existing value
         elseif (isset($myvalues[0][$name][0]))
@@ -427,6 +437,7 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 		$value = ( $value / $attr["MULTIPLIER"]);
 	}
 
+	// Action add_account
         elseif (isset($attr["DEFAULT"]) && ($action == 'add_account' || $action == 'add_domain'))
         {
             if (preg_match('/^=php\.(\w+)\((.*)\)$/',$attr["DEFAULT"],$matches))
@@ -473,6 +484,8 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 	// Hide values if SUBORDINATED to another
 	if (isset($attr["SUBORDINATED"]))
 	    $hidden = ($myvalues[0][strtolower($subordinated)][0] == "TRUE" ? null : 1);
+	if (isset($attr["SUBORDINATEDREVERSE"]))
+	    $hidden = ($myvalues[0][strtolower($subordinatedreverse)][0] == "FALSE" ? null : 1);
 	    
         if (!isset($hidden))
         {
@@ -491,18 +504,46 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 
 	}
         
+	// Options (select)
+	elseif (isset($attr["OPTIONS"]) && !isset($hidden))
+	{
+	    if ($_SESSION["login"]["level"] < $minAuthLevel)
+		$tag .= $value;
+	    else
+	    {
+		$tag .= '<select name="values['.$p_name.']['.$name.']">';
+		foreach ($attr["OPTIONS"] as $k => $v)
+		{
+		    $label = (isset($lang[$k]) ? $lang[$k] : $k);
+		    $selected = ($value == $v["VALUE"] ? 'selected="selected"' : '');
+		
+		    $tag .= '<option value="'.$v["VALUE"].'" '.$selected.'>'.$label.' ('.$v["VALUE"].')</option>'."\n";
+	    }
+		$tag .= '</select>'."\n\n";
+	    }
+	}
+        
 	elseif (isset($attr["DATE"]) && !isset($hidden))
 	{
-	    $current_date = (isset($value) ? $value : date('Y'.'-'.'m'.'-'.'d'));
-	    $tag .= date_input('values_date['.$p_name.']['.$name.']',$current_date,$format='ymd');
+	    $current_date = ($value ? $value : date('Y'.'-'.'m'.'-'.'d'));
+
+	    if ($_SESSION["login"]["level"] < $minAuthLevel)
+		$tag .= $value;
+	    else
+		$tag .= date_input('values_date['.$p_name.']['.$name.']',$current_date,$format='ymd');
 	}
         
 	elseif (isset($attr["TEXTAREA"]) && !isset($hidden))
         {
-            // Show box to add multiple values
-            $tag .= '<textarea name="values['.$p_name.']['.$name.']" cols="35" rows="5">';
-	    $tag .= stripslashes($value);
-	    $tag .= "</textarea><br/>";
+	    if ($_SESSION["login"]["level"] < $minAuthLevel)
+		$tag .= nl2br($value);
+	    else
+            {
+		// Show box to add multiple values
+		$tag .= '<textarea name="values['.$p_name.']['.$name.']" cols="35" rows="5">';
+		$tag .= stripslashes($value);
+		$tag .= "</textarea><br/>";
+	    }
 	}
 
         elseif (isset($attr["MULTIPLE"]) && !isset($hidden))
@@ -783,10 +824,10 @@ function navigation ($initial)
     global $action;
 
     $tag = '<div class="navigation">'."\n";
-    $tag .= '<a href="main.php?domain=NONE">'.$lang["all_domains"]."</a>"."\n";
+    $tag .= '<a href="main.php?domain=NONE&amp;initial=">'.$lang["all_domains"]."</a>"."\n";
     if ($domain)
     {
-        $tag .= " &gt; ".'<a href="main.php?action=domain_view&amp;mail=NONE&amp;domain='.$domain.'">';
+        $tag .= " &gt; ".'<a href="main.php?action=domain_view&amp;mail=NONE&amp;domain='.$domain.'&amp;initial=">';
         $tag .= $domain.'</a>'."\n";
     }
     if ($mail && $domain)
@@ -842,7 +883,6 @@ function navigation ($initial)
 
 /**
 * @author Alessandro De Zorzi <adezorzi@rhx.it>
-* @copyright Copyright &copy; 2005, Alessandro De Zorzi
 *
 * @return mixed
 **/
@@ -907,6 +947,8 @@ function action_select($group_actions)
     $tag .= '<tr>';
     $tag .= '<td class="note" colspan="2">';
     $tag .= '<select name="action">';
+    $tag .= '<option value="">'.$lang["select_an_action"].'</option>'."\n";
+    
     foreach ($group_actions as $action)
     {
 	$label = (isset($lang[$action]) ? $lang[$action] : $action);
@@ -952,7 +994,7 @@ function date_input($name,$current_date,$format='ymd')
     list($year,$month,$day) = split("-", $current_date);
 
     // Days
-    $tag .= '<select name="'.$name.'[day]" '.$class_string.'>';
+    $tag .= '<select name="'.$name.'[day]">';
     for ($i=1; $i<=31; $i++)
     {
 	$selected = ($i == $day ? 'selected="selected"' : '');
@@ -961,7 +1003,7 @@ function date_input($name,$current_date,$format='ymd')
     $tag .= "</select>";
 
     // Month
-    $tag .= '<select name="'.$name.'[month]" '.$class_string.'>';
+    $tag .= '<select name="'.$name.'[month]">';
     for ($i=1; $i<=12; $i++)
     {
 	$selected = ($i == $month ? 'selected="selected"' : '');
@@ -975,7 +1017,7 @@ function date_input($name,$current_date,$format='ymd')
     $min_year = ( $this_year - 1);
     $max_year = ( $this_year +4 );
 
-    $tag .=  '<select name="'.$name.'[year]" '.$class_string.'>';
+    $tag .=  '<select name="'.$name.'[year]">';
     for ($i=$min_year; $i<$max_year; $i++)
     {
 	$selected = ($i == $year ? 'selected="selected"' : '');
@@ -995,7 +1037,7 @@ function locale_select()
     global $supported_languages;
 
     $tag = '<form action="'.$_SERVER["PHP_SELF"].'" method="get" name="lang">';
-    $tag .= '<select name="language" class="" onchange="document.lang.submit()">'."\n";
+    $tag .= '<select name="language" onchange="document.lang.submit()">'."\n";
 	
     foreach ($supported_languages as $l_k => $l_v)
     {
