@@ -72,7 +72,7 @@ if (!login_check() && isset($_POST["login_username"]) && isset($_POST["login_pas
 // Logout
 if (isset($_GET["exit"]))
 {
-    phamm_log ($pn,$_SESSION["login"]["username"],'logout',1);
+    phamm_log ($_SESSION["phamm"]["pn"],$_SESSION["login"]["username"],'logout',1);
     
     logout();
 
@@ -106,7 +106,6 @@ elseif(login_check())
     if (!$r_bind)
 	refresh ( 'main.php?exit=1', $force_meta = false, REFRESH_TIME );
 
-
     if (!isset($_SESSION["phamm"]["pn"]))
         $_SESSION["phamm"]["pn"] = DEFAULT_PLUGIN;
 
@@ -332,13 +331,18 @@ case "insert_domain" :
 case "add_account" :
 
     $syntax = check_syntax('account',$_POST["account_new"]);
+    
+    $account_exists = phamm_list('vd='.$domain.','.LDAP_BASE,"(mail=".$_POST["account_new"]."@".$domain.")",array('mail'));
 
-    if ($syntax)
+    if ($syntax && $account_exists["count"] == 0)
         phamm_print_xhtml ( form_add_account_2 ($_POST["account_new"].'@'.$domain,'insert_account') );
 
     else
     {
-        phamm_print_message('error',$lang["warning"]);
+	if ($account_exists["count"] > 0)
+	    phamm_print_message('error',$lang["account_or_alias_exists"]);
+	if (!$syntax)
+	    phamm_print_message('error',$lang["warning"]);
         phamm_print_xhtml ( form_add_account ($_POST["account_new"]) );
     }
 
@@ -354,6 +358,17 @@ case "modify_account" :
     $cn = $values[0]["cn"][0];
     $sn = $values[0]["sn"][0];
 
+    // ////////////////////////////////////////////////////////////
+    // Static warning @todo
+    if (!($values[0]["amavisspamkilllevel"][0] >= $values[0]["amavisspamtag2level"][0] && $values[0]["amavisspamtag2level"][0] >= $values[0]["amavisspamtaglevel"][0]))
+        phamm_print_message ('warning',$lang["warning_spam_tag_level"]);
+    if ($values[0]["forwardactive"][0] == "TRUE" && isset($values[0]["vacationforward"]["count"]))
+        phamm_print_message ('warning',$lang["warning_double_forward"]);
+    if ($values[0]["forwardactive"][0] == "TRUE" && !isset($values[0]["maildrop"]))
+        phamm_print_message ('warning',$lang["warning_forward_destination_missed"]);
+    //
+    // ////////////////////////////////////////////////////////////
+
     phamm_print_xhtml ( form_add_account_2 ($values[0]["mail"][0], 'update_account') );
 
     break;
@@ -388,7 +403,7 @@ case "domain_view" :
     if (isset($pv[$pn]["ACCOUNT"]))
         $values = array_merge($values,$pv[$pn]["ACCOUNT"]);
 
-    phamm_print_xhtml ( accounts_list($domain,$values) );
+    phamm_print_xhtml ( accounts_list($domain,$values,$initial) );
     phamm_print_xhtml ( action_select($group_actions_accounts) );
 
     break;
@@ -457,7 +472,7 @@ case "insert_account" :
             }
         }
 
-        $mail						= $account_new;
+        $mail = $account_new;
         
 	// in mail.xml
 	// $uid = str_replace ( '@', CHR_UID_ACCOUNT, $mail);
@@ -526,12 +541,23 @@ case "insert_account" :
 		
 		$headers = '';
 		$headers .= "Message-ID: <".time()."@".$_SERVER['SERVER_NAME'].">".$eol;
-		$headers .= "X-Mailer: Phamm - PHP v".phpversion().$eol;
+		$headers .= "X-Mailer: PHP v".phpversion().$eol;
 
-		$headers .= "From: <".$welcome_sender.">".$eol;
+		## $headers .= "From: <".$welcome_sender.">".$eol;
+		$headers .= "From: <postmaster@".$domain.">".$eol;
 		$headers .= "Bcc: <".$welcome_bcc.">".$eol;
 
-		$r = mail($mail,$welcome_subject,$msg,$headers,'-f '.$welcome_sender);
+		// Skip Welcome Message if is a Catch-all account
+		if ($mail != '@'.$domain)
+		{
+		    $safe_mode_var = ini_get('safe_mode');
+
+		    // Skip 5th parameter if safe_mode=On in php.ini
+		    if ($safe_mode_var)
+			$r = mail($mail,$welcome_subject,$msg,$headers);
+		    else
+			$r = mail($mail,$welcome_subject,$msg,$headers,'-f postmaster@'.$domain);
+		}
 		phamm_log ($pn,$_SESSION["login"]["username"],'sent welcome message to '.$mail,$r);
 	    }
 
@@ -729,7 +755,7 @@ default :
     // @todo only one query...
     if ($_SESSION["login"]["level"] == 10)
     {
-	if (isset($initial))
+	if ($initial)
 	    $vds = phamm_list(LDAP_BASE,"(&(objectClass=virtualDomain)(vd=$initial*))",array('vd'));
 	else
 	    $vds = phamm_list(LDAP_BASE,'objectClass=virtualDomain',array('vd'));
